@@ -7,7 +7,7 @@ import logging
 
 
 def setup_module(thismodulebypytest):
-    logging.debug('setup_module-')
+    logging.debug("setup_module-")
 
 
 def session_00000():
@@ -25,12 +25,12 @@ def session_00001():
 
 
 def test_1(capsys):
-    logging.debug('test_1-')
+    logging.debug("test_1-")
 
 
 def test_2(capsys):
-    logging.debug('test_2-')
-    assert False    # fail the test case
+    logging.debug("test_2-")
+    assert False  # fail the test case
 
 
 def session_00002():
@@ -41,8 +41,8 @@ def session_00002():
 
 
 def test_3(capsys):
-    logging.debug('test_3-')
+    logging.debug("test_3-")
 
 
 def teardown_module():
-    logging.debug('teardown_module-')
+    logging.debug("teardown_module-")
