@@ -7,7 +7,7 @@ from phmdoctest.fixture import managenamespace
 
 
 @pytest.mark.skipif(sys.version_info < (3, 8), reason="requires >=py3.8")
-def test_code_21_output_32(managenamespace):
+def test_code_21(managenamespace):
     import sys
 
     a = 10
