@@ -17,7 +17,7 @@ def test_setup_teardown_fixture(_phm_setup_teardown, managenamespace):
     assert items == dict()
 
     # A module level global in the test file can't be modified.
-    with pytest.raises(AssertionError) as exc_info:
+    with pytest.raises(AttributeError) as exc_info:
         bogus_name = "pytestmark"
         logging.debug("tests- Trying to add %s", bogus_name)
         items = {bogus_name: 0}
@@ -28,20 +28,20 @@ def test_setup_teardown_fixture(_phm_setup_teardown, managenamespace):
 
     # See an update reflected in a copy.
     logging.debug("tests- trying an update, then a copy.")
-    more_items = {"zero": 0, "one": 1, "myset": set([7, 8, 9])}
+    more_items = {"zero": 0, "one": 1, "myset": {7, 8, 9}}
     managenamespace(operation="update", additions=more_items)
     copy_of_more_items = managenamespace(operation="copy")
     assert more_items == copy_of_more_items
     logging.debug("tests- copy is the same as the update additions.")
 
     # Try an unsupported operation
-    with pytest.raises(AssertionError):
+    with pytest.raises(ValueError):
         managenamespace(operation="bogus")
 
     # Try update, but no additions
-    with pytest.raises(AssertionError):
+    with pytest.raises(ValueError):
         managenamespace(operation="update")
 
     # Try update, but additions is not a mapping
-    with pytest.raises(AssertionError):
-        managenamespace(operation="update", additions=set([1, 2, 3]))
+    with pytest.raises(TypeError):
+        managenamespace(operation="update", additions={1, 2, 3})
